function [sys,E]=Hydrog(Z,l,m,varargin)
% Hydrog determines the bound state energies of a physical object in an  
%  hydrogenoic atom.
%
%  [sys,E]=Hydrog(Z,l,m,varargin) -- varargin states for various input arguments
%   	>> Z         = Charge number of the hydrogenoic atom
%   	>> l	       = Secondary quantum number (l > 0)
%   	>> m         = Mass of the physical object (with respect to mass electron)
%   	>> varargin  = Optional input arguments
%         >> nx    = Gate number on Ox axis (default value: 200)
%         >> nE    = Number of energy values (default: 1000)
%         >> Emin  = Lowest energy value (default: min(Ep))
%         >> Emax  = Highest energy value (default: 0)
%
% Olivier Pujol (2010)

%% Verifications

if (l==0),error('This example only holds for l > 0');end
if (Z<=0),error('One must have Z >= 1');end

%% Optional input arguments

switch length(varargin)
    case 0
        nx=200;                     % Default value of Ox gate number
        nE=1000;                    % Default value of energy values number
    case 1
        nx=varargin{1};             % Default value of Ox gate number
        nE=1000;                    % Default value of energy values number
    case 2
        nx=varargin{1};             % Default value of Ox gate number
        nE=varargin{2};             % Default value of energy values number
    case 4
        nx=varargin{1};             % Value of Ox gate number
        nE=varargin{2};             % Value of energy values number
        E=linspace(varargin{3},varargin{4},nE);              % Set of energy values
    otherwise
        ('Bad number of optional input arguments');
end

%% Potential energy

% Constants
Ry = 13.6058;                       % Rydberg (eV)
aB = 0.0529177;                     % Bohr radius (nm)

Ep0 = Z^2*Ry/(l*(l+1));             % Potential energy minimum
x0 = l*(l+1)*aB/Z;                  % Corresponding point

% Construction
x=linspace(x0/4,50*x0,nx);          % Spatial domain
Epc=2*Ep0.*(-(x0./x)+(x0^2./(2.*x.^2)));     % Coulombian + centrifuge potential energy. Origin is on well height

% Digitalization
[M,xt,Ep]=digitalization(x,Epc); 	% Digitalization
axis([0 50*x0 min(Epc) 0]);			% Plotting aspect

clear Ry aB Ep0 Epc x

% Energy values
if (length(varargin)~=4)
    E=linspace(min(Ep),Ep(end),nE);   % Set of energy values
end    

if (max(E)>0),error('Some energy values are out of bound state domain');end

%% Bound states

[sys,E]=Epot(M,xt,Ep,m,E);          % System 
sysconf(sys,E);                     % Bound states

return;