function [x,psi,rho]=psirho(sys,gate_spacing,xmin,xmax,TES,E)
% PSIRHO determines the wave function and the probability density of a 
%   physical object which interacts with a potential energy. 
%
%   [x,psi,rho]=PSIRHO(sys,pas,xmin,xmax)
%       >> sys 			= System
%       >> gate_spacing = Gate spacing on Ox-axis
%       >> xmin 		= Lowest limit on Ox axis
%       >> xmax 		= Highest limit on Ox axis 
%       << x 			= Position on axis Ox
%       << psi 			= Wave function complex amplitude 
%       << rho 			= Probability density
%
%   Olivier Pujol (2010)
%
%% Verifications

if (gate_spacing>=0.01),error('Step may be too large!');end
if ( (xmin>sys{1}{1}(5))||(xmax<sys{1}{1}(6)) ),error('System out of domain!');end

%% Scattering state or bounded state

iconf=input('Is a bound state ? yes (choose 1) / no (choose 0) ');

switch class(sys)
    case 'step' 
        [x,rho]=psirho(sys,gate_spacing,xmin,xmax);
    case 'cell'
        
%% Quanton energy En must be choosed. 
%  The gate iE corresponding to the lowest difference between En and E is taken

if (length(E)>=2)
    En=input('Choose a value for quanton energy: ');
    Ep=nan(1,length(sys{1}));
    Ep(1)=sys{1}{1}(1);
    for ic=2:length(sys{1})
        Ep(ic)=get(sys{1}{ic},'OutputPotentialEnergy');
    end

    iE=find(abs(abs(En-E)-min(abs(En-E)))<eps,1,'first');
end
if (length(E)==1),iE=1;end

%% Initialization

x=cell(1,length(sys{iE}));      % Spatial variable
psi=cell(1,length(sys{iE}));    % Wave function
rho=cell(1,length(sys{iE}));    % Probability density
    
%% Scattering states

if (iconf==0)
        
        % Computation in the input region
        x{1}=linspace(xmin,sys{iE}{1}(5),1+(sys{iE}{1}(5)-xmin)/gate_spacing);
        k=sys{iE}{1}(3);
        Amp=[1;-TES{iE}(2,1)/TES{iE}(2,2)];
        psi{1}=nan(size(x{1}));
        psi{1}=(1/sqrt(k))*( Amp(1)*exp(i*k*(x{1}-sys{iE}{1}(5))) ...
                            +Amp(2)*exp(-i*k*(x{1}-sys{iE}{1}(5))) );
        rho{1}=cell(size(x{1}));
        rho{1}=psi{1}.*conj(psi{1});
        
        % Computation in the other regions (except output one)
        for n=2:length(sys{iE})-1
            Amp=matrix(sys{iE}{n})*Amp;
            x1=get(sys{iE}{n},'Position');
            x2=get(sys{iE}{n+1},'Position');
            x{n}=linspace(x1,x2,1+(x2-x1)/gate_spacing);
            k=get(sys{iE}{n},'OutputWaveVector');
            psi{n}=nan(size(x{n}));
            psi{n}=(1/sqrt(k))*( Amp(1)*exp(i*k*(x{n}-x1)) ...
                                +Amp(2)*exp(-i*k*(x{n}-x1)) );
            rho{n}=nan(size(x{n}));
            rho{n}=psi{n}.*conj(psi{n});
            Amp=translation(sys{iE}{n},sys{iE}{n+1})*Amp;
        end

        % Computation in the output region
        x{n+1}=linspace(sys{iE}{1}(6),xmax,(xmax-sys{iE}{1}(6))/gate_spacing);
        k=sys{iE}{1}(4);
        psi{n+1}=nan(size(x{n+1}));
        psi{n+1}=(1/sqrt(k))*( (1/TES{iE}(2,2))*exp(i*k*(x{n+1}-sys{iE}{1}(6))) );
        rho{n+1}=nan(size(x{n+1}));
        rho{n+1}=psi{n+1}.*conj(psi{n+1});
end

%% Confined states

if (iconf==1)
        x{1}=linspace(xmin,sys{iE}{1}(5),1+(sys{iE}{1}(5)-xmin)/gate_spacing);
        k=sys{iE}{1}(3);
        Amp=[0;1];
        psi{1}=nan(size(x{1}));
        psi{1}=(1/sqrt(k))*( Amp(2)*exp(-i*k*(x{1}-sys{iE}{1}(5))) );
        rho{1}=nan(size(x{1}));
        rho{1}=psi{1}.*conj(psi{1});
        
        % Computation in the other regions (except output one)
        for n=2:length(sys{iE})-1
            Amp=matrix(sys{iE}{n})*Amp;
            x1=get(sys{iE}{n},'Position');
            x2=get(sys{iE}{n+1},'Position');
            x{n}=linspace(x1,x2,1+(x2-x1)/gate_spacing);
            k=get(sys{iE}{n},'OutputWaveVector');
            psi{n}=nan(size(x{n}));
            psi{n}=(1/sqrt(k))*( Amp(1)*exp(i*k*(x{n}-x1)) ...
                                +Amp(2)*exp(-i*k*(x{n}-x1)) );
            rho{n}=nan(size(x{n}));
            rho{n}=psi{n}.*conj(psi{n});
            Amp=translation(sys{iE}{n},sys{iE}{n+1})*Amp;
        end

        % Computation in the output region
        x{n+1}=linspace(sys{iE}{1}(6),xmax,(xmax-sys{iE}{1}(6))/gate_spacing);
        k=sys{iE}{1}(4);
        Amp=matrix(sys{iE}{length(sys{iE})})*Amp;
        psi{n+1}=nan(size(x{n+1}));
        psi{n+1}=(1/sqrt(k))*( Amp(1)*exp(i*k*(x{n+1}-sys{iE}{1}(6))) );
        rho{n+1}=nan(size(x{n+1}));
        rho{n+1}=psi{n+1}.*conj(psi{n+1});    

end 

        otherwise
        error('Bad argument type');

end

%% Normalization by the area under the curve of rho(x) between xmin and xmax.

area=0;
for iz=1:length(sys{iE})
area = area+sum((rho{iz}(1:end-1)+rho{iz}(2:end))*gate_spacing)/2;
end
for iz=1:length(sys{iE})
    rho{iz}=rho{iz}/area;
    psi{iz}=psi{iz}/sqrt(area);
end

clear Amp area iz

return;