function sysconf(sys,E)
% sysconf determines the bound state energies of a physical object confined 
%  in a well of potential energy. 
%  Also, a graphical representation of the well and these energies is proposed.
%
%	sysconf(sys,E)
%		>> sys 		= System
%		>> E		= Energy of the physical object
%
%	Olivier Pujol (2010)
%
if (nargin~=2);error('Bad number of input arguments!');end
if (isa(sys,'cell')==0),error('The first argument must be of type ''cell''!');end

%% Computing of the transfert matrix abcd of the well

TES=matrix(sys);

%% Extraction of element d

d=nan(1,length(TES));   % Initialization

for iT=1:size(TES,2)
    d(iT)=TES{iT}(2,2);   % Element d
end

clear TES

%% Graphical representation

%  Sketch of the well
L=get(sys{1}{length(sys{1})},'Position')-get(sys{1}{2},'Position'); % Well largeness
xmin=get(sys{1}{2},'Position')-0.5*L;                       % Minimum of abscissae (on Ox) 
xmax=get(sys{1}{length(sys{1})},'Position')+0.5*L;          % Maximum of abscissae (on Ox) 

pos=nan(1,length(sys{1})-1);    % Initialization of step position
Ep=nan(1,length(sys{1})-1);     % Initialization of step height
%
for i=2:length(sys{1})
    if (isa(sys{1}{i},'step')==0),error('Bad type of argument!');end
    pos(i-1)=get(sys{1}{i},'Position');
    Ep(i-1)=get(sys{1}{i},'OutputPotentialEnergy');
end
%
pos=[xmin pos xmax];
Ep_e=sys{1}{1}(1);
Ep_s=sys{1}{1}(2);
Ep=[Ep_e Ep Ep_s];

figure
subplot(1,2,1)
hs=stairs(pos,Ep);              % Sketch of the well 
set(hs,'LineWidth',2,'Color','b');
if (min(Ep)<0),axis([xmin xmax min(Ep) max(E)+0.1*abs(min(Ep))]);end
if (min(Ep)>=0),axis([xmin xmax min(Ep) max(E)+0.1*max(E)]);end
set(gca,'xminortick','on','yminortick','on');
grid on;
box on;
xlabel('{\itx} (nm)');
ylabel('Energy (eV)');
title('{Potential energy well}');

%   Energy bound states displaying. These states are obtaines, in principle, 
%   for d=0. Numerically, only the minima of d are considered because the finite number 
%   of E-values and the numerical approximation prevent from obtain rigourously a null  
%   value for d. Furthermore, in order to better show these minima, it is often better
%   to plot the natural logarithm of the absolute value of d. 
subplot(1,2,2);
plot(log(abs(d)),E,'b');
if (min(Ep)<0),axis([min(log(abs(d))) max(log(abs(d))) min(Ep) max(E)+0.1*abs(min(Ep))]);end
if (min(Ep)>=0),axis([min(log(abs(d))) max(log(abs(d))) min(Ep) max(E)+0.1*max(E)]);end
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
title('Bound state energies');
xlabel('ln(|d|)');
ylabel('Energie (eV)','Color','k');

return;
