function sysper(sys,E,period)
% SYSPER determines the allowed energy bands (conduction bands) and the 
%  forbidden ones (valence bands) of a physical object which interacts with a 
%  periodic potential energy. 
%  Also, a graphical representation of the potential energy and these energy 
%  bands is proposed.
%
%	sysper(sys,E,period)
%		>> sys		= System
%		>> E		= Energy of the physical object
%		>> period	= Spatial period of the potential energy 
%
%	Olivier Pujol (2010)
%
if (nargin~=3);error('Bad number of input arguments!');end
if (isa(sys,'cell')==0),error('The first argument must be of type ''cell'' !');end
if (period<=0);error('The periodicity of the potential energy must be positive!');end

%% Computing of the transfert matrix abcd of the periodic pattern

TES=matrix(sys);

%% Extraction of element a (real part of a is taken)

L=get(sys{1}{length(sys{1})},'Position')-get(sys{1}{2},'Position');     % Largeness of the pattern

if (period-L<=0),error('[Periodicity is too small: it must be great than the pattern largeness!]');end

ke=get(sys{1}{2},'InputWaveVector');		% Input wavevector
Re_a=nan(1,length(TES));					% Initialization

for n=1:size(TES,2)
    Re_a(n)=abs(real(TES{n}(1,1)*exp(1i*ke*(period-L))));    % Real part of a
end

clear TES

%% Graphical representation

% Sketch of the periodic pattern
xmin=get(sys{1}{2},'Position');                         % The pattern begins at the first step
xmax=get(sys{1}{length(sys{1})},'Position')+(pas-L);    % The output region (Ep=cte) of length period-L belongs to the pattern

pos=nan(1,length(sys{1})-1);    % Initialization
Ep=nan(1,length(sys{1})-1);     % Initialization
%
for i=2:length(sys{1})
    if (isa(sys{1}{i},'step')==0),error('Bad type argument!');end
    pos(i-1)=get(sys{1}{i},'Position');
    Ep(i-1)=get(sys{1}{i},'OutputPotentialEnergy');
end
%
pos=[xmin pos xmax];
Ep_e=sys{1}{1}(1);
Ep_s=sys{1}{1}(2);
Ep=[Ep_e Ep Ep_s];

figure
subplot(1,2,1)
hs=stairs(pos,Ep);
set(hs,'LineWidth',2,'Color','b');
axis([xmin-L xmax min(Ep) max(E)]);
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
xlabel('{\itx} (nm)');
title('{Potential energy (eV) of the pattern}');

% Sketch of the allowed energy bands
subplot(1,2,2);
plot(Re_a,E);
line([1 1],[0 max(E)],'LineWidth',2,'Color','r','LineStyle','--')
axis([0 1.1 min(E) max(E)])
set(gca,'xminortick','on','yminortick','on');
grid on;
box on
xlabel('| Re\{a\} |');
ylabel('Energy (eV)');
title('Allowed energy bands');
return;
